@@ -30,8 +30,6 @@
 
 #include <bonobo/bonobo-object.h>
 
-#include "GNOME_SettingsDaemon.h"
-
 typedef void (* KeyCallbackFunc) (GConfEntry *entry);
 
 void       gnome_settings_daemon_register_callback (const char      *dir,
@@ -54,14 +52,13 @@ typedef struct _GnomeSettingsDaemonPrivate GnomeSettingsDaemonPrivate;
 
 struct _GnomeSettingsDaemon
 {
-  BonoboObject parent_instance;
+  GObject parent_instance;
   GnomeSettingsDaemonPrivate *private;
 };
 
 struct _GnomeSettingsDaemonClass
 {
-  BonoboObjectClass parent_class;
-  POA_GNOME_SettingsDaemon__epv epv;
+  GObjectClass parent_class;
 };
 
 GType    gnome_settings_daemon_get_type         (void);
@@ -71,6 +68,11 @@ void     gnome_settings_daemon_spawn_with_input (char       **argv,
 
 GConfClient *gnome_settings_daemon_get_conf_client (void);
 
+/**
+ * DBUS server
+ */
+GType gnome_settings_server_get_type (void);
+
 G_END_DECLS
 
 #endif /* __GNOME_SETTINGS_DAEMON_H */
